/* contacts-address-map.c generated by valac 0.32.0.15-114e9, the Vala compiler
 * generated from contacts-address-map.vala, do not modify */

/* -*- Mode: vala; indent-tabs-mode: t; c-basic-offset: 2; tab-width: 8 -*- */
/*
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Author: Jonas Danielsson <jonas@threetimestwo.org>
 */

#include <glib.h>
#include <glib-object.h>
#include <gtk/gtk.h>
#include <gee.h>
#include <folks/folks.h>
#include <geocode-glib/geocode-glib.h>
#include <champlain/champlain.h>
#include <clutter-gtk/clutter-gtk.h>
#include <stdlib.h>
#include <string.h>
#include <gio/gdesktopappinfo.h>
#include <clutter/clutter.h>
#include <gdk/gdk.h>
#include <glib/gi18n-lib.h>
#include <gio/gio.h>
#include <gdk-pixbuf/gdk-pixbuf.h>
#include <cogl/cogl.h>
#include <float.h>
#include <math.h>


#define CONTACTS_TYPE_ADDRESS_MAP (contacts_address_map_get_type ())
#define CONTACTS_ADDRESS_MAP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), CONTACTS_TYPE_ADDRESS_MAP, ContactsAddressMap))
#define CONTACTS_ADDRESS_MAP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), CONTACTS_TYPE_ADDRESS_MAP, ContactsAddressMapClass))
#define CONTACTS_IS_ADDRESS_MAP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), CONTACTS_TYPE_ADDRESS_MAP))
#define CONTACTS_IS_ADDRESS_MAP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), CONTACTS_TYPE_ADDRESS_MAP))
#define CONTACTS_ADDRESS_MAP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), CONTACTS_TYPE_ADDRESS_MAP, ContactsAddressMapClass))

typedef struct _ContactsAddressMap ContactsAddressMap;
typedef struct _ContactsAddressMapClass ContactsAddressMapClass;
typedef struct _ContactsAddressMapPrivate ContactsAddressMapPrivate;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define __g_list_free__g_object_unref0_0(var) ((var == NULL) ? NULL : (var = (_g_list_free__g_object_unref0_ (var), NULL)))

#define CONTACTS_TYPE_CONTACT (contacts_contact_get_type ())
#define CONTACTS_CONTACT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), CONTACTS_TYPE_CONTACT, ContactsContact))
#define CONTACTS_CONTACT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), CONTACTS_TYPE_CONTACT, ContactsContactClass))
#define CONTACTS_IS_CONTACT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), CONTACTS_TYPE_CONTACT))
#define CONTACTS_IS_CONTACT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), CONTACTS_TYPE_CONTACT))
#define CONTACTS_CONTACT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), CONTACTS_TYPE_CONTACT, ContactsContactClass))

typedef struct _ContactsContact ContactsContact;
typedef struct _ContactsContactClass ContactsContactClass;
typedef struct _Block9Data Block9Data;
#define _g_free0(var) (var = (g_free (var), NULL))
typedef struct _ContactsContactPrivate ContactsContactPrivate;

#define CONTACTS_TYPE_STORE (contacts_store_get_type ())
#define CONTACTS_STORE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), CONTACTS_TYPE_STORE, ContactsStore))
#define CONTACTS_STORE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), CONTACTS_TYPE_STORE, ContactsStoreClass))
#define CONTACTS_IS_STORE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), CONTACTS_TYPE_STORE))
#define CONTACTS_IS_STORE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), CONTACTS_TYPE_STORE))
#define CONTACTS_STORE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), CONTACTS_TYPE_STORE, ContactsStoreClass))

typedef struct _ContactsStore ContactsStore;
typedef struct _ContactsStoreClass ContactsStoreClass;
#define _g_variant_unref0(var) ((var == NULL) ? NULL : (var = (g_variant_unref (var), NULL)))
typedef struct _Block10Data Block10Data;
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _Block11Data Block11Data;
#define _g_list_free0(var) ((var == NULL) ? NULL : (var = (g_list_free (var), NULL)))
#define __vala_ChamplainBoundingBox_free0(var) ((var == NULL) ? NULL : (var = (_vala_ChamplainBoundingBox_free (var), NULL)))

struct _ContactsAddressMap {
	GtkFrame parent_instance;
	ContactsAddressMapPrivate * priv;
};

struct _ContactsAddressMapClass {
	GtkFrameClass parent_class;
};

struct _ContactsAddressMapPrivate {
	GtkStack* map_stack;
	GtkGrid* map_grid;
	GtkImage* map_icon;
	GeeSet* addresses;
	GList* found_places;
	ChamplainView* map_view;
	ChamplainMarkerLayer* marker_layer;
	GMutex mutex;
	gulong alloc_id;
};

struct _Block9Data {
	int _ref_count_;
	ContactsAddressMap* self;
	GtkClutterEmbed* map;
	gchar* maps_id;
	ContactsContact* c;
};

struct _ContactsContact {
	GObject parent_instance;
	ContactsContactPrivate * priv;
	ContactsStore* store;
	gboolean is_main;
	FolksPresenceType presence_type;
	gchar* presence_message;
	gboolean is_phone;
	FolksIndividual* individual;
	FolksPersona* fake_persona;
};

struct _ContactsContactClass {
	GObjectClass parent_class;
};

struct _Block10Data {
	int _ref_count_;
	ContactsAddressMap* self;
	gint geocodes;
};

struct _Block11Data {
	int _ref_count_;
	ContactsAddressMap* self;
	GList* markers;
};


static gpointer contacts_address_map_parent_class = NULL;

GType contacts_address_map_get_type (void) G_GNUC_CONST;
#define CONTACTS_ADDRESS_MAP_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), CONTACTS_TYPE_ADDRESS_MAP, ContactsAddressMapPrivate))
enum  {
	CONTACTS_ADDRESS_MAP_DUMMY_PROPERTY
};
static void _g_object_unref0_ (gpointer var);
static void _g_list_free__g_object_unref0_ (GList* self);
GType contacts_contact_get_type (void) G_GNUC_CONST;
ContactsAddressMap* contacts_address_map_new (ContactsContact* c, GeeSet* postal_addresses);
ContactsAddressMap* contacts_address_map_construct (GType object_type, ContactsContact* c, GeeSet* postal_addresses);
static Block9Data* block9_data_ref (Block9Data* _data9_);
static void block9_data_unref (void * _userdata_);
static gboolean __lambda34_ (ContactsAddressMap* self);
static gboolean ___lambda34__clutter_actor_captured_event (ClutterActor* _sender, ClutterEvent* event, gpointer self);
static void ___lambda35_ (Block9Data* _data9_);
static void ____lambda35__gtk_widget_realize (GtkWidget* _sender, gpointer self);
static gboolean ___lambda36_ (Block9Data* _data9_);
void contacts_activate_action (const gchar* app_id, const gchar* action, GVariant* parameter, guint32 timestamp);
GType contacts_store_get_type (void) G_GNUC_CONST;
static gboolean ____lambda36__gtk_widget_button_press_event (GtkWidget* _sender, GdkEventButton* event, gpointer self);
void contacts_address_map_load (ContactsAddressMap* self);
static Block10Data* block10_data_ref (Block10Data* _data10_);
static void block10_data_unref (void * _userdata_);
void contacts_contact_geocode_address (FolksPostalAddress* addr, GAsyncReadyCallback _callback_, gpointer _user_data_);
GeocodePlace* contacts_contact_geocode_address_finish (GAsyncResult* _res_);
static void ____lambda37_ (Block10Data* _data10_, GObject* object, GAsyncResult* res);
static void contacts_address_map_show_map (ContactsAddressMap* self);
static void _____lambda37__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static void contacts_address_map_show_pin (ContactsAddressMap* self);
static void contacts_address_map_show_labels (ContactsAddressMap* self);
static void contacts_address_map_on_allocation_changed (ContactsAddressMap* self);
static Block11Data* block11_data_ref (Block11Data* _data11_);
static void block11_data_unref (void * _userdata_);
static gboolean __lambda38_ (Block11Data* _data11_);
static void _vala_ChamplainBoundingBox_free (ChamplainBoundingBox* self);
static gboolean ___lambda38__gsource_func (gpointer self);
static void _contacts_address_map_on_allocation_changed_clutter_actor_allocation_changed (ClutterActor* _sender, ClutterActorBox* box, ClutterAllocationFlags flags, gpointer self);
static void contacts_address_map_finalize (GObject* obj);
static void _vala_clear_GMutex (GMutex * mutex);
static void _vala_clear_GRecMutex (GRecMutex * mutex);
static void _vala_clear_GRWLock (GRWLock * mutex);
static void _vala_clear_GCond (GCond * mutex);


static void _g_object_unref0_ (gpointer var) {
#line 41 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	(var == NULL) ? NULL : (var = (g_object_unref (var), NULL));
#line 194 "contacts-address-map.c"
}


static void _g_list_free__g_object_unref0_ (GList* self) {
#line 41 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	g_list_foreach (self, (GFunc) _g_object_unref0_, NULL);
#line 41 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	g_list_free (self);
#line 203 "contacts-address-map.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 47 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	return self ? g_object_ref (self) : NULL;
#line 210 "contacts-address-map.c"
}


static Block9Data* block9_data_ref (Block9Data* _data9_) {
#line 47 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	g_atomic_int_inc (&_data9_->_ref_count_);
#line 47 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	return _data9_;
#line 219 "contacts-address-map.c"
}


static void block9_data_unref (void * _userdata_) {
	Block9Data* _data9_;
	_data9_ = (Block9Data*) _userdata_;
#line 47 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	if (g_atomic_int_dec_and_test (&_data9_->_ref_count_)) {
#line 228 "contacts-address-map.c"
		ContactsAddressMap* self;
#line 47 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
		self = _data9_->self;
#line 47 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
		_g_free0 (_data9_->maps_id);
#line 47 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
		_g_object_unref0 (_data9_->map);
#line 47 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
		_g_object_unref0 (_data9_->c);
#line 47 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
		_g_object_unref0 (self);
#line 47 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
		g_slice_free (Block9Data, _data9_);
#line 242 "contacts-address-map.c"
	}
}


static gboolean __lambda34_ (ContactsAddressMap* self) {
	gboolean result = FALSE;
#line 63 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	result = TRUE;
#line 63 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	return result;
#line 253 "contacts-address-map.c"
}


static gboolean ___lambda34__clutter_actor_captured_event (ClutterActor* _sender, ClutterEvent* event, gpointer self) {
	gboolean result;
	result = __lambda34_ ((ContactsAddressMap*) self);
#line 63 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	return result;
#line 262 "contacts-address-map.c"
}


static void ___lambda35_ (Block9Data* _data9_) {
	ContactsAddressMap* self;
	GtkClutterEmbed* _tmp0_ = NULL;
	GdkWindow* _tmp1_ = NULL;
	GdkCursor* _tmp2_ = NULL;
	GdkCursor* _tmp3_ = NULL;
#line 67 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	self = _data9_->self;
#line 68 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_tmp0_ = _data9_->map;
#line 68 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_tmp1_ = gtk_widget_get_window ((GtkWidget*) _tmp0_);
#line 68 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_tmp2_ = gdk_cursor_new (GDK_HAND1);
#line 68 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_tmp3_ = _tmp2_;
#line 68 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	gdk_window_set_cursor (_tmp1_, _tmp3_);
#line 68 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_g_object_unref0 (_tmp3_);
#line 286 "contacts-address-map.c"
}


static void ____lambda35__gtk_widget_realize (GtkWidget* _sender, gpointer self) {
#line 67 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	___lambda35_ (self);
#line 293 "contacts-address-map.c"
}


static gboolean ___lambda36_ (Block9Data* _data9_) {
	ContactsAddressMap* self;
	gboolean result = FALSE;
	const gchar* _tmp0_ = NULL;
	ContactsContact* _tmp1_ = NULL;
	FolksIndividual* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	const gchar* _tmp4_ = NULL;
	GVariant* _tmp5_ = NULL;
	GVariant* _tmp6_ = NULL;
	guint32 _tmp7_ = 0U;
#line 71 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	self = _data9_->self;
#line 72 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_tmp0_ = _data9_->maps_id;
#line 72 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_tmp1_ = _data9_->c;
#line 72 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_tmp2_ = _tmp1_->individual;
#line 72 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_tmp3_ = folks_individual_get_id (_tmp2_);
#line 72 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_tmp4_ = _tmp3_;
#line 72 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_tmp5_ = g_variant_new ("s", _tmp4_, NULL);
#line 72 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	g_variant_ref_sink (_tmp5_);
#line 72 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_tmp6_ = _tmp5_;
#line 72 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_tmp7_ = gtk_get_current_event_time ();
#line 72 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	contacts_activate_action (_tmp0_, "show-contact", _tmp6_, _tmp7_);
#line 72 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_g_variant_unref0 (_tmp6_);
#line 76 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	result = TRUE;
#line 76 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	return result;
#line 336 "contacts-address-map.c"
}


static gboolean ____lambda36__gtk_widget_button_press_event (GtkWidget* _sender, GdkEventButton* event, gpointer self) {
	gboolean result;
	result = ___lambda36_ (self);
#line 71 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	return result;
#line 345 "contacts-address-map.c"
}


ContactsAddressMap* contacts_address_map_construct (GType object_type, ContactsContact* c, GeeSet* postal_addresses) {
	ContactsAddressMap * self = NULL;
	Block9Data* _data9_;
	ContactsContact* _tmp0_ = NULL;
	ContactsContact* _tmp1_ = NULL;
	GtkClutterEmbed* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	GDesktopAppInfo* maps_info = NULL;
	const gchar* _tmp4_ = NULL;
	gchar* _tmp5_ = NULL;
	gchar* _tmp6_ = NULL;
	GDesktopAppInfo* _tmp7_ = NULL;
	GDesktopAppInfo* _tmp8_ = NULL;
	ChamplainMapSourceFactory* map_factory = NULL;
	ChamplainMapSourceFactory* _tmp9_ = NULL;
	GtkGrid* _tmp10_ = NULL;
	GtkClutterEmbed* _tmp11_ = NULL;
	ChamplainView* _tmp12_ = NULL;
	ChamplainView* _tmp13_ = NULL;
	ChamplainMapSourceFactory* _tmp14_ = NULL;
	ChamplainMapSource* _tmp15_ = NULL;
	ChamplainView* _tmp16_ = NULL;
	ChamplainView* _tmp17_ = NULL;
	guint _tmp18_ = 0U;
	guint _tmp19_ = 0U;
	GtkClutterEmbed* _tmp20_ = NULL;
	ClutterActor* _tmp21_ = NULL;
	ChamplainView* _tmp22_ = NULL;
	ChamplainMarkerLayer* _tmp23_ = NULL;
	ChamplainView* _tmp24_ = NULL;
	ChamplainMarkerLayer* _tmp25_ = NULL;
	GtkClutterEmbed* _tmp26_ = NULL;
	ClutterActor* _tmp27_ = NULL;
	GDesktopAppInfo* _tmp28_ = NULL;
	GeeSet* _tmp33_ = NULL;
	GeeSet* _tmp34_ = NULL;
#line 47 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	g_return_val_if_fail (c != NULL, NULL);
#line 47 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	g_return_val_if_fail (postal_addresses != NULL, NULL);
#line 47 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_data9_ = g_slice_new0 (Block9Data);
#line 47 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_data9_->_ref_count_ = 1;
#line 47 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_tmp0_ = c;
#line 47 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 47 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_g_object_unref0 (_data9_->c);
#line 47 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_data9_->c = _tmp1_;
#line 47 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	self = (ContactsAddressMap*) g_object_new (object_type, NULL);
#line 47 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_data9_->self = g_object_ref (self);
#line 48 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_tmp2_ = (GtkClutterEmbed*) gtk_clutter_embed_new ();
#line 48 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	g_object_ref_sink (_tmp2_);
#line 48 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_data9_->map = _tmp2_;
#line 49 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_tmp3_ = g_strdup ("org.gnome.Maps");
#line 49 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_data9_->maps_id = _tmp3_;
#line 50 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_tmp4_ = _data9_->maps_id;
#line 50 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_tmp5_ = g_strconcat (_tmp4_, ".desktop", NULL);
#line 50 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_tmp6_ = _tmp5_;
#line 50 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_tmp7_ = g_desktop_app_info_new (_tmp6_);
#line 50 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_tmp8_ = _tmp7_;
#line 50 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_g_free0 (_tmp6_);
#line 50 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	maps_info = _tmp8_;
#line 51 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_tmp9_ = champlain_map_source_factory_dup_default ();
#line 51 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	map_factory = _tmp9_;
#line 52 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_tmp10_ = self->priv->map_grid;
#line 52 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_tmp11_ = _data9_->map;
#line 52 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	gtk_container_add ((GtkContainer*) _tmp10_, (GtkWidget*) _tmp11_);
#line 54 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_tmp12_ = (ChamplainView*) champlain_view_new ();
#line 54 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	g_object_ref_sink (_tmp12_);
#line 54 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_g_object_unref0 (self->priv->map_view);
#line 54 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	self->priv->map_view = _tmp12_;
#line 55 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_tmp13_ = self->priv->map_view;
#line 55 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_tmp14_ = map_factory;
#line 55 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_tmp15_ = champlain_map_source_factory_create (_tmp14_, CHAMPLAIN_MAP_SOURCE_OSM_MAPQUEST);
#line 55 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	champlain_view_set_map_source (_tmp13_, _tmp15_);
#line 56 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_tmp16_ = self->priv->map_view;
#line 56 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_tmp17_ = self->priv->map_view;
#line 56 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_tmp18_ = champlain_view_get_max_zoom_level (_tmp17_);
#line 56 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_tmp19_ = _tmp18_;
#line 56 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	champlain_view_set_zoom_level (_tmp16_, _tmp19_ - 2);
#line 57 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_tmp20_ = _data9_->map;
#line 57 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_tmp21_ = gtk_clutter_embed_get_stage (_tmp20_);
#line 57 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_tmp22_ = self->priv->map_view;
#line 57 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	clutter_actor_add_child (_tmp21_, (ClutterActor*) _tmp22_);
#line 59 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_tmp23_ = champlain_marker_layer_new ();
#line 59 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	g_object_ref_sink (_tmp23_);
#line 59 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_g_object_unref0 (self->priv->marker_layer);
#line 59 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	self->priv->marker_layer = _tmp23_;
#line 60 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_tmp24_ = self->priv->map_view;
#line 60 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_tmp25_ = self->priv->marker_layer;
#line 60 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	champlain_view_add_layer (_tmp24_, (ChamplainLayer*) _tmp25_);
#line 63 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_tmp26_ = _data9_->map;
#line 63 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_tmp27_ = gtk_clutter_embed_get_stage (_tmp26_);
#line 63 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	g_signal_connect_object (_tmp27_, "captured-event", (GCallback) ___lambda34__clutter_actor_captured_event, self, 0);
#line 65 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_tmp28_ = maps_info;
#line 65 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	if (_tmp28_ != NULL) {
#line 497 "contacts-address-map.c"
		GtkClutterEmbed* _tmp29_ = NULL;
		GtkClutterEmbed* _tmp30_ = NULL;
#line 67 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
		_tmp29_ = _data9_->map;
#line 67 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
		g_signal_connect_data ((GtkWidget*) _tmp29_, "realize", (GCallback) ____lambda35__gtk_widget_realize, block9_data_ref (_data9_), (GClosureNotify) block9_data_unref, 0);
#line 71 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
		_tmp30_ = _data9_->map;
#line 71 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
		g_signal_connect_data ((GtkWidget*) _tmp30_, "button-press-event", (GCallback) ____lambda36__gtk_widget_button_press_event, block9_data_ref (_data9_), (GClosureNotify) block9_data_unref, 0);
#line 508 "contacts-address-map.c"
	} else {
		GtkClutterEmbed* _tmp31_ = NULL;
		const gchar* _tmp32_ = NULL;
#line 80 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
		_tmp31_ = _data9_->map;
#line 80 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
		_tmp32_ = _ ("Install GNOME Maps to open location.");
#line 80 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
		gtk_widget_set_tooltip_text ((GtkWidget*) _tmp31_, _tmp32_);
#line 518 "contacts-address-map.c"
	}
#line 83 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_tmp33_ = postal_addresses;
#line 83 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_tmp34_ = _g_object_ref0 (_tmp33_);
#line 83 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_g_object_unref0 (self->priv->addresses);
#line 83 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	self->priv->addresses = _tmp34_;
#line 84 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	__g_list_free__g_object_unref0_0 (self->priv->found_places);
#line 84 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	self->priv->found_places = NULL;
#line 85 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_vala_clear_GMutex (&self->priv->mutex);
#line 85 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	g_mutex_init (&self->priv->mutex);
#line 47 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_g_object_unref0 (map_factory);
#line 47 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_g_object_unref0 (maps_info);
#line 47 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	block9_data_unref (_data9_);
#line 47 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_data9_ = NULL;
#line 47 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	return self;
#line 546 "contacts-address-map.c"
}


ContactsAddressMap* contacts_address_map_new (ContactsContact* c, GeeSet* postal_addresses) {
#line 47 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	return contacts_address_map_construct (CONTACTS_TYPE_ADDRESS_MAP, c, postal_addresses);
#line 553 "contacts-address-map.c"
}


static Block10Data* block10_data_ref (Block10Data* _data10_) {
#line 88 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	g_atomic_int_inc (&_data10_->_ref_count_);
#line 88 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	return _data10_;
#line 562 "contacts-address-map.c"
}


static void block10_data_unref (void * _userdata_) {
	Block10Data* _data10_;
	_data10_ = (Block10Data*) _userdata_;
#line 88 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	if (g_atomic_int_dec_and_test (&_data10_->_ref_count_)) {
#line 571 "contacts-address-map.c"
		ContactsAddressMap* self;
#line 88 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
		self = _data10_->self;
#line 88 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
		_g_object_unref0 (self);
#line 88 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
		g_slice_free (Block10Data, _data10_);
#line 579 "contacts-address-map.c"
	}
}


static void ____lambda37_ (Block10Data* _data10_, GObject* object, GAsyncResult* res) {
	ContactsAddressMap* self;
	GeocodePlace* place = NULL;
	GAsyncResult* _tmp0_ = NULL;
	GeocodePlace* _tmp1_ = NULL;
	gint _tmp2_ = 0;
	GeocodePlace* _tmp3_ = NULL;
	gboolean _tmp6_ = FALSE;
	gint _tmp7_ = 0;
	GeeSet* _tmp8_ = NULL;
	gint _tmp9_ = 0;
	gint _tmp10_ = 0;
#line 93 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	self = _data10_->self;
#line 93 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	g_return_if_fail (res != NULL);
#line 94 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	g_mutex_lock (&self->priv->mutex);
#line 96 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_tmp0_ = res;
#line 96 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_tmp1_ = contacts_contact_geocode_address_finish (_tmp0_);
#line 96 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	place = _tmp1_;
#line 97 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_tmp2_ = _data10_->geocodes;
#line 97 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_data10_->geocodes = _tmp2_ + 1;
#line 99 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_tmp3_ = place;
#line 99 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	if (_tmp3_ != NULL) {
#line 616 "contacts-address-map.c"
		GeocodePlace* _tmp4_ = NULL;
		GeocodePlace* _tmp5_ = NULL;
#line 100 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
		_tmp4_ = place;
#line 100 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
		_tmp5_ = _g_object_ref0 (_tmp4_);
#line 100 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
		self->priv->found_places = g_list_prepend (self->priv->found_places, _tmp5_);
#line 625 "contacts-address-map.c"
	}
#line 102 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_tmp7_ = _data10_->geocodes;
#line 102 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_tmp8_ = self->priv->addresses;
#line 102 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_tmp9_ = gee_collection_get_size ((GeeCollection*) _tmp8_);
#line 102 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_tmp10_ = _tmp9_;
#line 102 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	if (_tmp7_ == _tmp10_) {
#line 637 "contacts-address-map.c"
		GList* _tmp11_ = NULL;
		guint _tmp12_ = 0U;
#line 102 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
		_tmp11_ = self->priv->found_places;
#line 102 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
		_tmp12_ = g_list_length (_tmp11_);
#line 102 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
		_tmp6_ = _tmp12_ > ((guint) 0);
#line 646 "contacts-address-map.c"
	} else {
#line 102 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
		_tmp6_ = FALSE;
#line 650 "contacts-address-map.c"
	}
#line 102 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	if (_tmp6_) {
#line 103 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
		contacts_address_map_show_map (self);
#line 656 "contacts-address-map.c"
	}
#line 105 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	g_mutex_unlock (&self->priv->mutex);
#line 93 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_g_object_unref0 (place);
#line 662 "contacts-address-map.c"
}


static void _____lambda37__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 93 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	____lambda37_ (self, source_object, res);
#line 93 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	block10_data_unref (self);
#line 671 "contacts-address-map.c"
}


void contacts_address_map_load (ContactsAddressMap* self) {
	Block10Data* _data10_;
	GtkStack* _tmp0_ = NULL;
	GtkImage* _tmp1_ = NULL;
#line 88 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	g_return_if_fail (self != NULL);
#line 88 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_data10_ = g_slice_new0 (Block10Data);
#line 88 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_data10_->_ref_count_ = 1;
#line 88 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_data10_->self = g_object_ref (self);
#line 89 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_tmp0_ = self->priv->map_stack;
#line 89 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_tmp1_ = self->priv->map_icon;
#line 89 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	gtk_stack_set_visible_child (_tmp0_, (GtkWidget*) _tmp1_);
#line 90 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_data10_->geocodes = 0;
#line 695 "contacts-address-map.c"
	{
		GeeIterator* _addr_it = NULL;
		GeeSet* _tmp2_ = NULL;
		GeeIterator* _tmp3_ = NULL;
#line 92 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
		_tmp2_ = self->priv->addresses;
#line 92 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
		_tmp3_ = gee_iterable_iterator ((GeeIterable*) _tmp2_);
#line 92 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
		_addr_it = _tmp3_;
#line 92 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
		while (TRUE) {
#line 708 "contacts-address-map.c"
			GeeIterator* _tmp4_ = NULL;
			gboolean _tmp5_ = FALSE;
			FolksPostalAddressFieldDetails* addr = NULL;
			GeeIterator* _tmp6_ = NULL;
			gpointer _tmp7_ = NULL;
			FolksPostalAddressFieldDetails* _tmp8_ = NULL;
			gconstpointer _tmp9_ = NULL;
			FolksPostalAddress* _tmp10_ = NULL;
#line 92 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
			_tmp4_ = _addr_it;
#line 92 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
			_tmp5_ = gee_iterator_next (_tmp4_);
#line 92 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
			if (!_tmp5_) {
#line 92 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
				break;
#line 725 "contacts-address-map.c"
			}
#line 92 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
			_tmp6_ = _addr_it;
#line 92 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
			_tmp7_ = gee_iterator_get (_tmp6_);
#line 92 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
			addr = (FolksPostalAddressFieldDetails*) _tmp7_;
#line 93 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
			_tmp8_ = addr;
#line 93 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
			_tmp9_ = folks_abstract_field_details_get_value ((FolksAbstractFieldDetails*) _tmp8_);
#line 93 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
			_tmp10_ = _tmp9_;
#line 93 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
			contacts_contact_geocode_address ((FolksPostalAddress*) _tmp10_, _____lambda37__gasync_ready_callback, block10_data_ref (_data10_));
#line 92 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
			_g_object_unref0 (addr);
#line 743 "contacts-address-map.c"
		}
#line 92 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
		_g_object_unref0 (_addr_it);
#line 747 "contacts-address-map.c"
	}
#line 88 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	block10_data_unref (_data10_);
#line 88 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_data10_ = NULL;
#line 753 "contacts-address-map.c"
}


static void contacts_address_map_show_pin (ContactsAddressMap* self) {
	GtkIconTheme* theme = NULL;
	GtkIconTheme* _tmp0_ = NULL;
	GtkIconTheme* _tmp1_ = NULL;
	ClutterActor* actor = NULL;
	ClutterActor* _tmp2_ = NULL;
	ChamplainMarker* marker = NULL;
	ChamplainMarker* _tmp22_ = NULL;
	GeocodePlace* place = NULL;
	GList* _tmp23_ = NULL;
	gconstpointer _tmp24_ = NULL;
	GeocodePlace* _tmp25_ = NULL;
	GeocodeLocation* _tmp26_ = NULL;
	GeocodeLocation* _tmp27_ = NULL;
	gdouble _tmp28_ = 0.0;
	gdouble _tmp29_ = 0.0;
	GeocodeLocation* _tmp30_ = NULL;
	GeocodeLocation* _tmp31_ = NULL;
	gdouble _tmp32_ = 0.0;
	gdouble _tmp33_ = 0.0;
	ClutterActor* _tmp34_ = NULL;
	ChamplainMarkerLayer* _tmp35_ = NULL;
	GError * _inner_error_ = NULL;
#line 110 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	g_return_if_fail (self != NULL);
#line 111 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_tmp0_ = gtk_icon_theme_get_default ();
#line 111 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 111 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	theme = _tmp1_;
#line 112 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_tmp2_ = clutter_actor_new ();
#line 112 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	g_object_ref_sink (_tmp2_);
#line 112 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	actor = _tmp2_;
#line 794 "contacts-address-map.c"
	{
		GdkPixbuf* pixbuf = NULL;
		GtkIconTheme* _tmp3_ = NULL;
		GdkPixbuf* _tmp4_ = NULL;
		ClutterImage* image = NULL;
		ClutterImage* _tmp5_ = NULL;
		ClutterImage* _tmp6_ = NULL;
		GdkPixbuf* _tmp7_ = NULL;
		guint8* _tmp8_ = NULL;
		GdkPixbuf* _tmp9_ = NULL;
		gint _tmp10_ = 0;
		GdkPixbuf* _tmp11_ = NULL;
		gint _tmp12_ = 0;
		GdkPixbuf* _tmp13_ = NULL;
		gint _tmp14_ = 0;
		ClutterActor* _tmp15_ = NULL;
		ClutterImage* _tmp16_ = NULL;
		ClutterActor* _tmp17_ = NULL;
		GdkPixbuf* _tmp18_ = NULL;
		gint _tmp19_ = 0;
		GdkPixbuf* _tmp20_ = NULL;
		gint _tmp21_ = 0;
#line 115 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
		_tmp3_ = theme;
#line 115 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
		_tmp4_ = gtk_icon_theme_load_icon (_tmp3_, "mark-location", 32, 0, &_inner_error_);
#line 115 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
		pixbuf = _tmp4_;
#line 115 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 825 "contacts-address-map.c"
			goto __catch2_g_error;
		}
#line 116 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
		_tmp5_ = clutter_image_new ();
#line 116 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
		image = _tmp5_;
#line 118 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
		_tmp6_ = image;
#line 118 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
		_tmp7_ = pixbuf;
#line 118 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
		_tmp8_ = gdk_pixbuf_get_pixels (_tmp7_);
#line 118 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
		_tmp9_ = pixbuf;
#line 118 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
		_tmp10_ = gdk_pixbuf_get_width (_tmp9_);
#line 118 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
		_tmp11_ = pixbuf;
#line 118 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
		_tmp12_ = gdk_pixbuf_get_height (_tmp11_);
#line 118 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
		_tmp13_ = pixbuf;
#line 118 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
		_tmp14_ = gdk_pixbuf_get_rowstride (_tmp13_);
#line 118 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
		clutter_image_set_data (_tmp6_, _tmp8_, COGL_PIXEL_FORMAT_RGBA_8888, (guint) _tmp10_, (guint) _tmp12_, (guint) _tmp14_, &_inner_error_);
#line 118 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 118 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
			_g_object_unref0 (image);
#line 118 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
			_g_object_unref0 (pixbuf);
#line 858 "contacts-address-map.c"
			goto __catch2_g_error;
		}
#line 125 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
		_tmp15_ = actor;
#line 125 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
		_tmp16_ = image;
#line 125 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
		clutter_actor_set_content (_tmp15_, (ClutterContent*) _tmp16_);
#line 126 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
		_tmp17_ = actor;
#line 126 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
		_tmp18_ = pixbuf;
#line 126 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
		_tmp19_ = gdk_pixbuf_get_width (_tmp18_);
#line 126 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
		_tmp20_ = pixbuf;
#line 126 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
		_tmp21_ = gdk_pixbuf_get_height (_tmp20_);
#line 126 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
		clutter_actor_set_size (_tmp17_, (gfloat) _tmp19_, (gfloat) _tmp21_);
#line 114 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
		_g_object_unref0 (image);
#line 114 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
		_g_object_unref0 (pixbuf);
#line 883 "contacts-address-map.c"
	}
	goto __finally2;
	__catch2_g_error:
	{
		GError* e = NULL;
#line 114 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
		e = _inner_error_;
#line 114 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
		_inner_error_ = NULL;
#line 114 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
		_g_error_free0 (e);
#line 895 "contacts-address-map.c"
	}
	__finally2:
#line 114 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 114 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
		_g_object_unref0 (actor);
#line 114 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
		_g_object_unref0 (theme);
#line 114 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 114 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
		g_clear_error (&_inner_error_);
#line 114 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
		return;
#line 910 "contacts-address-map.c"
	}
#line 132 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_tmp22_ = (ChamplainMarker*) champlain_marker_new ();
#line 132 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	g_object_ref_sink (_tmp22_);
#line 132 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	marker = _tmp22_;
#line 133 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_tmp23_ = self->priv->found_places;
#line 133 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_tmp24_ = g_list_nth_data (_tmp23_, (guint) 0);
#line 133 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_tmp25_ = _g_object_ref0 ((GeocodePlace*) _tmp24_);
#line 133 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	place = _tmp25_;
#line 135 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_tmp26_ = geocode_place_get_location (place);
#line 135 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_tmp27_ = _tmp26_;
#line 135 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	g_object_get (_tmp27_, "latitude", &_tmp28_, NULL);
#line 135 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_tmp29_ = _tmp28_;
#line 135 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	g_object_set ((ChamplainLocation*) marker, "latitude", _tmp29_, NULL);
#line 136 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_tmp30_ = geocode_place_get_location (place);
#line 136 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_tmp31_ = _tmp30_;
#line 136 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	g_object_get (_tmp31_, "longitude", &_tmp32_, NULL);
#line 136 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_tmp33_ = _tmp32_;
#line 136 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	g_object_set ((ChamplainLocation*) marker, "longitude", _tmp33_, NULL);
#line 138 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_tmp34_ = actor;
#line 138 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	clutter_actor_add_child ((ClutterActor*) marker, _tmp34_);
#line 139 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_tmp35_ = self->priv->marker_layer;
#line 139 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	champlain_marker_layer_add_marker (_tmp35_, marker);
#line 110 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_g_object_unref0 (place);
#line 110 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_g_object_unref0 (marker);
#line 110 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_g_object_unref0 (actor);
#line 110 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_g_object_unref0 (theme);
#line 962 "contacts-address-map.c"
}


static void contacts_address_map_show_labels (ContactsAddressMap* self) {
	GList* _tmp0_ = NULL;
#line 142 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	g_return_if_fail (self != NULL);
#line 143 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_tmp0_ = self->priv->found_places;
#line 972 "contacts-address-map.c"
	{
		GList* place_collection = NULL;
		GList* place_it = NULL;
#line 143 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
		place_collection = _tmp0_;
#line 143 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
		for (place_it = place_collection; place_it != NULL; place_it = place_it->next) {
#line 980 "contacts-address-map.c"
			GeocodePlace* _tmp1_ = NULL;
			GeocodePlace* place = NULL;
#line 143 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
			_tmp1_ = _g_object_ref0 ((GeocodePlace*) place_it->data);
#line 143 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
			place = _tmp1_;
#line 987 "contacts-address-map.c"
			{
				ChamplainLabel* label = NULL;
				ChamplainLabel* _tmp2_ = NULL;
				GeocodePlace* _tmp3_ = NULL;
				const gchar* _tmp4_ = NULL;
				const gchar* _tmp5_ = NULL;
				ChamplainLabel* _tmp14_ = NULL;
				GeocodePlace* _tmp15_ = NULL;
				GeocodeLocation* _tmp16_ = NULL;
				GeocodeLocation* _tmp17_ = NULL;
				gdouble _tmp18_ = 0.0;
				gdouble _tmp19_ = 0.0;
				ChamplainLabel* _tmp20_ = NULL;
				GeocodePlace* _tmp21_ = NULL;
				GeocodeLocation* _tmp22_ = NULL;
				GeocodeLocation* _tmp23_ = NULL;
				gdouble _tmp24_ = 0.0;
				gdouble _tmp25_ = 0.0;
				ChamplainMarkerLayer* _tmp26_ = NULL;
				ChamplainLabel* _tmp27_ = NULL;
#line 144 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
				_tmp2_ = (ChamplainLabel*) champlain_label_new ();
#line 144 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
				g_object_ref_sink (_tmp2_);
#line 144 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
				label = _tmp2_;
#line 148 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
				_tmp3_ = place;
#line 148 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
				_tmp4_ = geocode_place_get_street_address (_tmp3_);
#line 148 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
				_tmp5_ = _tmp4_;
#line 148 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
				if (_tmp5_ != NULL) {
#line 1022 "contacts-address-map.c"
					ChamplainLabel* _tmp6_ = NULL;
					GeocodePlace* _tmp7_ = NULL;
					const gchar* _tmp8_ = NULL;
					const gchar* _tmp9_ = NULL;
#line 149 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
					_tmp6_ = label;
#line 149 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
					_tmp7_ = place;
#line 149 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
					_tmp8_ = geocode_place_get_street_address (_tmp7_);
#line 149 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
					_tmp9_ = _tmp8_;
#line 149 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
					champlain_label_set_text (_tmp6_, _tmp9_);
#line 1037 "contacts-address-map.c"
				} else {
					ChamplainLabel* _tmp10_ = NULL;
					GeocodePlace* _tmp11_ = NULL;
					const gchar* _tmp12_ = NULL;
					const gchar* _tmp13_ = NULL;
#line 151 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
					_tmp10_ = label;
#line 151 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
					_tmp11_ = place;
#line 151 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
					_tmp12_ = geocode_place_get_street (_tmp11_);
#line 151 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
					_tmp13_ = _tmp12_;
#line 151 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
					champlain_label_set_text (_tmp10_, _tmp13_);
#line 1053 "contacts-address-map.c"
				}
#line 153 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
				_tmp14_ = label;
#line 153 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
				_tmp15_ = place;
#line 153 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
				_tmp16_ = geocode_place_get_location (_tmp15_);
#line 153 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
				_tmp17_ = _tmp16_;
#line 153 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
				g_object_get (_tmp17_, "latitude", &_tmp18_, NULL);
#line 153 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
				_tmp19_ = _tmp18_;
#line 153 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
				g_object_set ((ChamplainLocation*) _tmp14_, "latitude", _tmp19_, NULL);
#line 154 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
				_tmp20_ = label;
#line 154 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
				_tmp21_ = place;
#line 154 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
				_tmp22_ = geocode_place_get_location (_tmp21_);
#line 154 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
				_tmp23_ = _tmp22_;
#line 154 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
				g_object_get (_tmp23_, "longitude", &_tmp24_, NULL);
#line 154 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
				_tmp25_ = _tmp24_;
#line 154 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
				g_object_set ((ChamplainLocation*) _tmp20_, "longitude", _tmp25_, NULL);
#line 155 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
				_tmp26_ = self->priv->marker_layer;
#line 155 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
				_tmp27_ = label;
#line 155 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
				champlain_marker_layer_add_marker (_tmp26_, (ChamplainMarker*) _tmp27_);
#line 143 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
				_g_object_unref0 (label);
#line 143 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
				_g_object_unref0 (place);
#line 1093 "contacts-address-map.c"
			}
		}
	}
}


static Block11Data* block11_data_ref (Block11Data* _data11_) {
#line 159 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	g_atomic_int_inc (&_data11_->_ref_count_);
#line 159 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	return _data11_;
#line 1105 "contacts-address-map.c"
}


static void block11_data_unref (void * _userdata_) {
	Block11Data* _data11_;
	_data11_ = (Block11Data*) _userdata_;
#line 159 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	if (g_atomic_int_dec_and_test (&_data11_->_ref_count_)) {
#line 1114 "contacts-address-map.c"
		ContactsAddressMap* self;
#line 159 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
		self = _data11_->self;
#line 159 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
		_g_list_free0 (_data11_->markers);
#line 159 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
		_g_object_unref0 (self);
#line 159 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
		g_slice_free (Block11Data, _data11_);
#line 1124 "contacts-address-map.c"
	}
}


static void _vala_ChamplainBoundingBox_free (ChamplainBoundingBox* self) {
#line 171 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	g_boxed_free (champlain_bounding_box_get_type (), self);
#line 1132 "contacts-address-map.c"
}


static gboolean __lambda38_ (Block11Data* _data11_) {
	ContactsAddressMap* self;
	gboolean result = FALSE;
	GList* _tmp0_ = NULL;
	guint _tmp1_ = 0U;
#line 170 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	self = _data11_->self;
#line 171 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_tmp0_ = self->priv->found_places;
#line 171 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_tmp1_ = g_list_length (_tmp0_);
#line 171 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	if (_tmp1_ == ((guint) 1)) {
#line 1149 "contacts-address-map.c"
		GeocodePlace* place = NULL;
		GList* _tmp2_ = NULL;
		gconstpointer _tmp3_ = NULL;
		GeocodePlace* _tmp4_ = NULL;
		ChamplainView* _tmp5_ = NULL;
		GeocodePlace* _tmp6_ = NULL;
		GeocodeLocation* _tmp7_ = NULL;
		GeocodeLocation* _tmp8_ = NULL;
		gdouble _tmp9_ = 0.0;
		gdouble _tmp10_ = 0.0;
		GeocodePlace* _tmp11_ = NULL;
		GeocodeLocation* _tmp12_ = NULL;
		GeocodeLocation* _tmp13_ = NULL;
		gdouble _tmp14_ = 0.0;
		gdouble _tmp15_ = 0.0;
#line 172 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
		_tmp2_ = self->priv->found_places;
#line 172 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
		_tmp3_ = g_list_nth_data (_tmp2_, (guint) 0);
#line 172 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
		_tmp4_ = _g_object_ref0 ((GeocodePlace*) _tmp3_);
#line 172 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
		place = _tmp4_;
#line 174 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
		_tmp5_ = self->priv->map_view;
#line 174 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
		_tmp6_ = place;
#line 174 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
		_tmp7_ = geocode_place_get_location (_tmp6_);
#line 174 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
		_tmp8_ = _tmp7_;
#line 174 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
		g_object_get (_tmp8_, "latitude", &_tmp9_, NULL);
#line 174 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
		_tmp10_ = _tmp9_;
#line 174 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
		_tmp11_ = place;
#line 174 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
		_tmp12_ = geocode_place_get_location (_tmp11_);
#line 174 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
		_tmp13_ = _tmp12_;
#line 174 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
		g_object_get (_tmp13_, "longitude", &_tmp14_, NULL);
#line 174 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
		_tmp15_ = _tmp14_;
#line 174 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
		champlain_view_center_on (_tmp5_, _tmp10_, _tmp15_);
#line 171 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
		_g_object_unref0 (place);
#line 1199 "contacts-address-map.c"
	} else {
		ChamplainBoundingBox* bbox = NULL;
		ChamplainBoundingBox* _tmp16_ = NULL;
		GList* _tmp17_ = NULL;
		ChamplainView* _tmp50_ = NULL;
		ChamplainBoundingBox* _tmp51_ = NULL;
#line 177 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
		_tmp16_ = champlain_bounding_box_new ();
#line 177 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
		bbox = _tmp16_;
#line 180 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
		_tmp17_ = _data11_->markers;
#line 1212 "contacts-address-map.c"
		{
			GList* marker_collection = NULL;
			GList* marker_it = NULL;
#line 180 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
			marker_collection = _tmp17_;
#line 180 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
			for (marker_it = marker_collection; marker_it != NULL; marker_it = marker_it->next) {
#line 1220 "contacts-address-map.c"
				ClutterActor* marker = NULL;
#line 180 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
				marker = (ClutterActor*) marker_it->data;
#line 1224 "contacts-address-map.c"
				{
					gdouble x = 0.0;
					ChamplainView* _tmp18_ = NULL;
					ClutterActor* _tmp19_ = NULL;
					gdouble _tmp20_ = 0.0;
					gdouble _tmp21_ = 0.0;
					gdouble _tmp22_ = 0.0;
					gdouble y = 0.0;
					ChamplainView* _tmp23_ = NULL;
					ClutterActor* _tmp24_ = NULL;
					gdouble _tmp25_ = 0.0;
					gdouble _tmp26_ = 0.0;
					gdouble _tmp27_ = 0.0;
					gdouble lat = 0.0;
					ChamplainView* _tmp28_ = NULL;
					gdouble _tmp29_ = 0.0;
					ClutterActor* _tmp30_ = NULL;
					gfloat _tmp31_ = 0.0F;
					gfloat _tmp32_ = 0.0F;
					gdouble _tmp33_ = 0.0;
					gdouble lon = 0.0;
					ChamplainView* _tmp34_ = NULL;
					gdouble _tmp35_ = 0.0;
					ClutterActor* _tmp36_ = NULL;
					gfloat _tmp37_ = 0.0F;
					gfloat _tmp38_ = 0.0F;
					gdouble _tmp39_ = 0.0;
					ChamplainBoundingBox* _tmp40_ = NULL;
					gdouble _tmp41_ = 0.0;
					gdouble _tmp42_ = 0.0;
					ChamplainBoundingBox* _tmp43_ = NULL;
					ClutterActor* _tmp44_ = NULL;
					gdouble _tmp45_ = 0.0;
					gdouble _tmp46_ = 0.0;
					ClutterActor* _tmp47_ = NULL;
					gdouble _tmp48_ = 0.0;
					gdouble _tmp49_ = 0.0;
#line 181 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
					_tmp18_ = self->priv->map_view;
#line 181 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
					_tmp19_ = marker;
#line 181 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
					g_object_get ((ChamplainLocation*) (G_TYPE_CHECK_INSTANCE_TYPE (_tmp19_, champlain_marker_get_type ()) ? ((ChamplainMarker*) _tmp19_) : NULL), "longitude", &_tmp20_, NULL);
#line 181 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
					_tmp21_ = _tmp20_;
#line 181 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
					_tmp22_ = champlain_view_longitude_to_x (_tmp18_, _tmp21_);
#line 181 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
					x = _tmp22_;
#line 182 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
					_tmp23_ = self->priv->map_view;
#line 182 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
					_tmp24_ = marker;
#line 182 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
					g_object_get ((ChamplainLocation*) (G_TYPE_CHECK_INSTANCE_TYPE (_tmp24_, champlain_marker_get_type ()) ? ((ChamplainMarker*) _tmp24_) : NULL), "latitude", &_tmp25_, NULL);
#line 182 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
					_tmp26_ = _tmp25_;
#line 182 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
					_tmp27_ = champlain_view_latitude_to_y (_tmp23_, _tmp26_);
#line 182 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
					y = _tmp27_;
#line 185 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
					_tmp28_ = self->priv->map_view;
#line 185 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
					_tmp29_ = y;
#line 185 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
					_tmp30_ = marker;
#line 185 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
					_tmp31_ = clutter_actor_get_height (_tmp30_);
#line 185 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
					_tmp32_ = _tmp31_;
#line 185 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
					_tmp33_ = champlain_view_y_to_latitude (_tmp28_, _tmp29_ - (_tmp32_ * 256));
#line 185 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
					lat = _tmp33_;
#line 186 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
					_tmp34_ = self->priv->map_view;
#line 186 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
					_tmp35_ = x;
#line 186 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
					_tmp36_ = marker;
#line 186 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
					_tmp37_ = clutter_actor_get_width (_tmp36_);
#line 186 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
					_tmp38_ = _tmp37_;
#line 186 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
					_tmp39_ = champlain_view_x_to_longitude (_tmp34_, _tmp35_ + (_tmp38_ * 256));
#line 186 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
					lon = _tmp39_;
#line 188 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
					_tmp40_ = bbox;
#line 188 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
					_tmp41_ = lat;
#line 188 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
					_tmp42_ = lon;
#line 188 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
					champlain_bounding_box_extend (_tmp40_, _tmp41_, _tmp42_);
#line 189 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
					_tmp43_ = bbox;
#line 189 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
					_tmp44_ = marker;
#line 189 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
					g_object_get ((ChamplainLocation*) (G_TYPE_CHECK_INSTANCE_TYPE (_tmp44_, champlain_marker_get_type ()) ? ((ChamplainMarker*) _tmp44_) : NULL), "latitude", &_tmp45_, NULL);
#line 189 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
					_tmp46_ = _tmp45_;
#line 189 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
					_tmp47_ = marker;
#line 189 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
					g_object_get ((ChamplainLocation*) (G_TYPE_CHECK_INSTANCE_TYPE (_tmp47_, champlain_marker_get_type ()) ? ((ChamplainMarker*) _tmp47_) : NULL), "longitude", &_tmp48_, NULL);
#line 189 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
					_tmp49_ = _tmp48_;
#line 189 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
					champlain_bounding_box_extend (_tmp43_, _tmp46_, _tmp49_);
#line 1338 "contacts-address-map.c"
				}
			}
		}
#line 192 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
		_tmp50_ = self->priv->map_view;
#line 192 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
		_tmp51_ = bbox;
#line 192 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
		champlain_view_ensure_visible (_tmp50_, _tmp51_, FALSE);
#line 171 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
		__vala_ChamplainBoundingBox_free0 (bbox);
#line 1350 "contacts-address-map.c"
	}
#line 195 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	result = FALSE;
#line 195 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	return result;
#line 1356 "contacts-address-map.c"
}


static gboolean ___lambda38__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda38_ (self);
#line 170 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	return result;
#line 1365 "contacts-address-map.c"
}


static void contacts_address_map_on_allocation_changed (ContactsAddressMap* self) {
	Block11Data* _data11_;
	gulong _tmp0_ = 0UL;
	ChamplainMarkerLayer* _tmp1_ = NULL;
	GList* _tmp2_ = NULL;
	GList* _tmp3_ = NULL;
	gconstpointer _tmp4_ = NULL;
	ClutterActor* _tmp5_ = NULL;
	gfloat _tmp6_ = 0.0F;
	gfloat _tmp7_ = 0.0F;
	ChamplainMarkerLayer* _tmp8_ = NULL;
	gulong _tmp9_ = 0UL;
#line 159 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	g_return_if_fail (self != NULL);
#line 159 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_data11_ = g_slice_new0 (Block11Data);
#line 159 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_data11_->_ref_count_ = 1;
#line 159 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_data11_->self = g_object_ref (self);
#line 160 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_tmp0_ = self->priv->alloc_id;
#line 160 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	if (_tmp0_ == ((gulong) 0)) {
#line 161 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
		block11_data_unref (_data11_);
#line 161 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
		_data11_ = NULL;
#line 161 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
		return;
#line 1399 "contacts-address-map.c"
	}
#line 163 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_tmp1_ = self->priv->marker_layer;
#line 163 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_tmp2_ = clutter_actor_get_children (G_TYPE_CHECK_INSTANCE_TYPE (_tmp1_, clutter_actor_get_type ()) ? ((ClutterActor*) _tmp1_) : NULL);
#line 163 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_data11_->markers = _tmp2_;
#line 164 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_tmp3_ = _data11_->markers;
#line 164 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_tmp4_ = g_list_nth_data (_tmp3_, (guint) 0);
#line 164 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_tmp5_ = (ClutterActor*) _tmp4_;
#line 164 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_tmp6_ = clutter_actor_get_height ((ClutterActor*) (G_TYPE_CHECK_INSTANCE_TYPE (_tmp5_, champlain_marker_get_type ()) ? ((ChamplainMarker*) _tmp5_) : NULL));
#line 164 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_tmp7_ = _tmp6_;
#line 164 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	if (_tmp7_ == ((gfloat) 0)) {
#line 165 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
		block11_data_unref (_data11_);
#line 165 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
		_data11_ = NULL;
#line 165 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
		return;
#line 1425 "contacts-address-map.c"
	}
#line 167 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_tmp8_ = self->priv->marker_layer;
#line 167 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_tmp9_ = self->priv->alloc_id;
#line 167 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	g_signal_handler_disconnect ((GObject*) _tmp8_, _tmp9_);
#line 168 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	self->priv->alloc_id = (gulong) 0;
#line 170 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	g_idle_add_full (G_PRIORITY_DEFAULT_IDLE, ___lambda38__gsource_func, block11_data_ref (_data11_), block11_data_unref);
#line 159 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	block11_data_unref (_data11_);
#line 159 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_data11_ = NULL;
#line 1441 "contacts-address-map.c"
}


static void _contacts_address_map_on_allocation_changed_clutter_actor_allocation_changed (ClutterActor* _sender, ClutterActorBox* box, ClutterAllocationFlags flags, gpointer self) {
#line 216 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	contacts_address_map_on_allocation_changed ((ContactsAddressMap*) self);
#line 1448 "contacts-address-map.c"
}


static void contacts_address_map_show_map (ContactsAddressMap* self) {
	GList* _tmp0_ = NULL;
	guint _tmp1_ = 0U;
	GList* _tmp4_ = NULL;
	guint _tmp5_ = 0U;
	GtkStack* _tmp6_ = NULL;
	GtkGrid* _tmp7_ = NULL;
	ChamplainMarkerLayer* _tmp8_ = NULL;
	gulong _tmp9_ = 0UL;
#line 199 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	g_return_if_fail (self != NULL);
#line 200 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_tmp0_ = self->priv->found_places;
#line 200 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_tmp1_ = g_list_length (_tmp0_);
#line 200 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	if (_tmp1_ == ((guint) 0)) {
#line 1469 "contacts-address-map.c"
		GtkStack* _tmp2_ = NULL;
		GtkImage* _tmp3_ = NULL;
#line 201 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
		_tmp2_ = self->priv->map_stack;
#line 201 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
		_tmp3_ = self->priv->map_icon;
#line 201 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
		gtk_stack_set_visible_child (_tmp2_, (GtkWidget*) _tmp3_);
#line 202 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
		return;
#line 1480 "contacts-address-map.c"
	}
#line 205 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_tmp4_ = self->priv->found_places;
#line 205 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_tmp5_ = g_list_length (_tmp4_);
#line 205 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	if (_tmp5_ == ((guint) 1)) {
#line 206 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
		contacts_address_map_show_pin (self);
#line 1490 "contacts-address-map.c"
	} else {
#line 208 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
		contacts_address_map_show_labels (self);
#line 1494 "contacts-address-map.c"
	}
#line 211 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_tmp6_ = self->priv->map_stack;
#line 211 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_tmp7_ = self->priv->map_grid;
#line 211 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	gtk_stack_set_visible_child (_tmp6_, (GtkWidget*) _tmp7_);
#line 216 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_tmp8_ = self->priv->marker_layer;
#line 216 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_tmp9_ = g_signal_connect_object ((ClutterActor*) _tmp8_, "allocation-changed", (GCallback) _contacts_address_map_on_allocation_changed_clutter_actor_allocation_changed, self, 0);
#line 216 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	self->priv->alloc_id = _tmp9_;
#line 1508 "contacts-address-map.c"
}


static void contacts_address_map_class_init (ContactsAddressMapClass * klass) {
	gint ContactsAddressMap_private_offset;
#line 29 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	contacts_address_map_parent_class = g_type_class_peek_parent (klass);
#line 29 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	g_type_class_add_private (klass, sizeof (ContactsAddressMapPrivate));
#line 29 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	G_OBJECT_CLASS (klass)->finalize = contacts_address_map_finalize;
#line 29 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	ContactsAddressMap_private_offset = g_type_class_get_instance_private_offset (klass);
#line 29 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	gtk_widget_class_set_template_from_resource (GTK_WIDGET_CLASS (klass), "/org/gnome/contacts/ui/contacts-address-map.ui");
#line 29 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "map_stack", FALSE, ContactsAddressMap_private_offset + G_STRUCT_OFFSET (ContactsAddressMapPrivate, map_stack));
#line 29 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "map_grid", FALSE, ContactsAddressMap_private_offset + G_STRUCT_OFFSET (ContactsAddressMapPrivate, map_grid));
#line 29 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "map_icon", FALSE, ContactsAddressMap_private_offset + G_STRUCT_OFFSET (ContactsAddressMapPrivate, map_icon));
#line 1530 "contacts-address-map.c"
}


static void contacts_address_map_instance_init (ContactsAddressMap * self) {
#line 29 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	self->priv = CONTACTS_ADDRESS_MAP_GET_PRIVATE (self);
#line 45 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	self->priv->alloc_id = (gulong) 0;
#line 29 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	gtk_widget_init_template (GTK_WIDGET (self));
#line 1541 "contacts-address-map.c"
}


static void contacts_address_map_finalize (GObject* obj) {
	ContactsAddressMap * self;
#line 29 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, CONTACTS_TYPE_ADDRESS_MAP, ContactsAddressMap);
#line 32 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_g_object_unref0 (self->priv->map_stack);
#line 35 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_g_object_unref0 (self->priv->map_grid);
#line 38 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_g_object_unref0 (self->priv->map_icon);
#line 40 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_g_object_unref0 (self->priv->addresses);
#line 41 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	__g_list_free__g_object_unref0_0 (self->priv->found_places);
#line 42 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_g_object_unref0 (self->priv->map_view);
#line 43 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_g_object_unref0 (self->priv->marker_layer);
#line 44 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	_vala_clear_GMutex (&self->priv->mutex);
#line 29 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-address-map.vala"
	G_OBJECT_CLASS (contacts_address_map_parent_class)->finalize (obj);
#line 1567 "contacts-address-map.c"
}


GType contacts_address_map_get_type (void) {
	static volatile gsize contacts_address_map_type_id__volatile = 0;
	if (g_once_init_enter (&contacts_address_map_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (ContactsAddressMapClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) contacts_address_map_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ContactsAddressMap), 0, (GInstanceInitFunc) contacts_address_map_instance_init, NULL };
		GType contacts_address_map_type_id;
		contacts_address_map_type_id = g_type_register_static (gtk_frame_get_type (), "ContactsAddressMap", &g_define_type_info, 0);
		g_once_init_leave (&contacts_address_map_type_id__volatile, contacts_address_map_type_id);
	}
	return contacts_address_map_type_id__volatile;
}


static void _vala_clear_GMutex (GMutex * mutex) {
	GMutex zero_mutex = { 0 };
	if (memcmp (mutex, &zero_mutex, sizeof (GMutex))) {
		g_mutex_clear (mutex);
		memset (mutex, 0, sizeof (GMutex));
	}
}


static void _vala_clear_GRecMutex (GRecMutex * mutex) {
	GRecMutex zero_mutex = { 0 };
	if (memcmp (mutex, &zero_mutex, sizeof (GRecMutex))) {
		g_rec_mutex_clear (mutex);
		memset (mutex, 0, sizeof (GRecMutex));
	}
}


static void _vala_clear_GRWLock (GRWLock * mutex) {
	GRWLock zero_mutex = { 0 };
	if (memcmp (mutex, &zero_mutex, sizeof (GRWLock))) {
		g_rw_lock_clear (mutex);
		memset (mutex, 0, sizeof (GRWLock));
	}
}


static void _vala_clear_GCond (GCond * mutex) {
	GCond zero_mutex = { 0 };
	if (memcmp (mutex, &zero_mutex, sizeof (GCond))) {
		g_cond_clear (mutex);
		memset (mutex, 0, sizeof (GCond));
	}
}



